//=========================================================
//  MusE
//  Linux Music Editor
//  $Id: midisyncimpl.h,v 1.1.1.1 2003/10/29 10:06:29 wschweer Exp $
//
//  (C) Copyright 1999/2000 Werner Schweer (ws@seh.de)
//=========================================================

#ifndef __MIDISYNCIMPL_H__
#define __MIDISYNCIMPL_H__

#include "midisync.h"

//---------------------------------------------------------
//   MSConfig
//---------------------------------------------------------

class MidiSyncConfig : public MidiSyncConfigBase {
      Q_OBJECT

   private slots:
      void syncChanged(int);
      void ok();
      void cancel();
      void apply();

   public:
      MidiSyncConfig(QWidget* parent=0, const char* name=0);
      MidiSyncConfig();
      };

#endif

